@@ -6,6 +6,7 @@
 #![cfg_attr(all(test, feature = "vmtest"), feature(custom_test_frameworks))]
 #![cfg_attr(all(test, feature = "vmtest"), test_runner(x86test::runner::runner))]
 
+use core::arch::asm;
 #[cfg(target_arch = "x86")]
 pub(crate) use core::arch::x86 as arch;
 #[cfg(target_arch = "x86_64")]
@@ -116,9 +117,12 @@ mod x86testing {
 /// May fail with #UD if rdpid is not supported (check CPUID).
 #[inline(always)]
 pub unsafe fn rdpid() -> u64 {
+    #[cfg(target_pointer_width = "64")]
     let mut pid: u64;
+    #[cfg(target_pointer_width = "32")]
+    let mut pid: u32;
     asm!("rdpid {pid}", pid = out(reg) pid, options(att_syntax));
-    pid
+    pid.into()
 }
 
 #[cfg(all(test, feature = "utest"))]
